@@ -66,12 +66,28 @@
 #define TITRAQ_DEFBAKON         1
 #define TITRAQ_PREFEXTENDON     "filextension"
 #define TITRAQ_DEFEXTENDON      1
+#define TITRAQ_PREFDETAILON     "detailisting"
+#define TITRAQ_DEFDETAILON      0
+#define TITRAQ_PREFSIGNATON     "signatureline"
+#define TITRAQ_DEFSIGNATON      0
 #define TITRAQ_PREFREPORTYPE    "reportperiod"
 #define TITRAQ_DEFREPORTYPE     TITRAQ_REPORTWEEK
 #define TITRAQ_PREFREPORTWEEKS  "reportweeks"
 #define TITRAQ_DEFREPORTWEEKS   1
 #define TITRAQ_PREFREPORTMONTHS "reportmonths"
 #define TITRAQ_DEFREPORTMONTHS  1
+#define TITRAQ_PREFLIGHTRED     "lightred"
+#define TITRAQ_DEFLIGHTRED      248
+#define TITRAQ_PREFLIGHTGREEN   "lightgreen"
+#define TITRAQ_DEFLIGHTGREEN    248
+#define TITRAQ_PREFLIGHTBLUE    "lightblue"
+#define TITRAQ_DEFLIGHTBLUE     240
+#define TITRAQ_PREFDARKRED      "darkred"
+#define TITRAQ_DEFDARKRED       224
+#define TITRAQ_PREFDARKGREEN    "darkgreen"
+#define TITRAQ_DEFDARKGREEN     224
+#define TITRAQ_PREFDARKBLUE     "darkblue"
+#define TITRAQ_DEFDARKBLUE      216
 
 // Column show preferences
 #define TITRAQ_PREFSTATCOLON    "statcolshow"
