@@ -31,10 +31,13 @@
 
 #include <vector>
 
+#include <qimage.h>
+
 #include "as_panel.h"
 #include "as_generic.h"
 #include "as_const.h"
 
+#include "as_gfx/revcolour.xpm"
 
 //
 // Constructs a Prefpanel as a child of 'pParent', with the 
@@ -51,7 +54,11 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 
     this->setSizeGripEnabled(false);
     this->setSizePolicy(QSizePolicy((QSizePolicy::SizeType)5,
-        (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth()));
+        (QSizePolicy::SizeType)5, 0, 0, this->sizePolicy().hasHeightForWidth()));
+
+    // Initialize our button colours
+    m_pLight = new QColor();
+    m_pDark = new QColor();
 
     m_pVlayout = new QVBoxLayout(this, 11, 6, "Formlayout");
     m_pTabselect = new QTabWidget(this, "Tabselector");
@@ -79,12 +86,12 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     for (QStringList::Iterator Stylename = Styles.begin();
         Stylename != Styles.end(); Stylename++) {
         Stylevector[nIter] = new QRadioButton(m_pStylegroup, *Stylename + "_button");
-        Stylevector[nIter]->setText(tr(*Stylename, "Comment for " + *Stylename));
+        Stylevector[nIter]->setText(trUtf8(*Stylename, "Comment for " + *Stylename));
         Stylevector[nIter]->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding,
             Stylevector[nIter]->sizePolicy().hasHeightForWidth());
-        QToolTip::add(Stylevector[nIter], tr("The " + *Stylename + " style",
+        QToolTip::add(Stylevector[nIter], trUtf8("The " + *Stylename + " style",
             "Comment for toolTip " + *Stylename));
-        QWhatsThis::add(Stylevector[nIter], tr("Click this button to enjoy the style of the "
+        QWhatsThis::add(Stylevector[nIter], trUtf8("Click this button to enjoy the style of the "
             + *Stylename + " user interface", "Comment whatsThis for " + *Stylename));
         m_pStylelay->addWidget(Stylevector[nIter]);
         nIter++;
@@ -101,16 +108,16 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 
     // Optional file backups with hard coded extension .bak
     m_pBackupcheck = new QCheckBox(m_pSwitchgroup, "Backupbutton");
-    m_pBackupcheck->setText(tr("Make .bak file on save", "Comment for Backupcheck"));
-    QToolTip::add(m_pBackupcheck, tr("Will make a .bak file when saving", "Comment for toolTip Backupcheck"));
-    QWhatsThis::add(m_pBackupcheck, tr("Check this box to enable automatic file backups when overwriting an existing file", "Comment whatsThis for Backupcheck"));
+    m_pBackupcheck->setText(trUtf8("Make .bak file on save", "Comment for Backupcheck"));
+    QToolTip::add(m_pBackupcheck, trUtf8("Make a .bak file when saving", "Comment for toolTip Backupcheck"));
+    QWhatsThis::add(m_pBackupcheck, trUtf8("Check this box to enable automatic file backups when overwriting an existing file", "Comment whatsThis for Backupcheck"));
     m_pSwitchlay->addWidget(m_pBackupcheck);
 
     // Optional easy filename appending with hard coded extension .as
     m_pExtendcheck = new QCheckBox(m_pSwitchgroup, "Extensionbutton");
-    m_pExtendcheck->setText(tr("Append .as extension", "Comment for Extensioncheck"));
-    QToolTip::add(m_pExtendcheck, tr("Use the .as file extension", "Comment for toolTip Extensioncheck"));
-    QWhatsThis::add(m_pExtendcheck, tr("Check this box to automatically append '.as' to new filenames when saving", "Comment whatsThis for Extensioncheck"));
+    m_pExtendcheck->setText(trUtf8("Append .as extension", "Comment for Extensioncheck"));
+    QToolTip::add(m_pExtendcheck, trUtf8("Use the .as file extension", "Comment for toolTip Extensioncheck"));
+    QWhatsThis::add(m_pExtendcheck, trUtf8("Check this box to automatically append '.as' to new filenames when saving", "Comment whatsThis for Extensioncheck"));
     m_pSwitchlay->addWidget(m_pExtendcheck);
 
     // Start of report option UI pieces (like detailed report listings)
@@ -124,18 +131,17 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 
     // Optional detailed report listings write all events in range
     m_pDetailcheck = new QCheckBox(m_pReportgroup, "Detailistbutton");
-    m_pDetailcheck->setText(tr("Detailed listing", "Comment for Detailcheck"));
-    QToolTip::add(m_pDetailcheck, tr("Write detailed event listings", "Comment for toolTip Detailcheck"));
-    QWhatsThis::add(m_pDetailcheck, tr("Check this box to enable writing of detailed event listings to the local report", "Comment whatsThis for Detailcheck"));
+    m_pDetailcheck->setText(trUtf8("Detailed listing", "Comment for Detailcheck"));
+    QToolTip::add(m_pDetailcheck, trUtf8("Write detailed event listings", "Comment for toolTip Detailcheck"));
+    QWhatsThis::add(m_pDetailcheck, trUtf8("Check this box to enable writing of detailed event listings to the local report", "Comment whatsThis for Detailcheck"));
     m_pReportlay->addWidget(m_pDetailcheck);
 
     // Optional signature line in report footer
     m_pSigncheck = new QCheckBox(m_pReportgroup, "Signaturebutton");
-    m_pSigncheck->setText(tr("Signature line", "Comment for Signaturecheck"));
-    QToolTip::add(m_pSigncheck, tr("Append a signature line", "Comment for toolTip Signaturecheck"));
-    QWhatsThis::add(m_pSigncheck, tr("Check this box to write a signature line to the report footer", "Comment whatsThis for Signaturecheck"));
+    m_pSigncheck->setText(trUtf8("Signature line", "Comment for Signaturecheck"));
+    QToolTip::add(m_pSigncheck, trUtf8("Append a signature line", "Comment for toolTip Signaturecheck"));
+    QWhatsThis::add(m_pSigncheck, trUtf8("Check this box to write a signature line to the report footer", "Comment whatsThis for Signaturecheck"));
     m_pReportlay->addWidget(m_pSigncheck);
-
     m_pBoolayout->addWidget(m_pStylegroup);
     m_pBinlayout->addWidget(m_pReportgroup);
     m_pBinlayout->addWidget(m_pSwitchgroup);
@@ -146,7 +152,6 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     m_pGeneralpage = new QWidget(m_pTabselect, "Generalpage");
     m_pGenlayout = new QHBoxLayout(m_pGeneralpage, 11, 6, "Genlayout");
     m_pGenbox = new QGroupBox(m_pGeneralpage, "Groupboxlayout");
-
     m_pGenbox->setColumnLayout(0, Qt::Vertical);
     m_pGenbox->layout()->setSpacing(6);
     m_pGenbox->layout()->setMargin(11);
@@ -208,6 +213,60 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     m_pRemlayout->addWidget(m_pRembox);
     m_pTabselect->insertTab(m_pRemotepage, "");
 
+    // Start of color page UI pieces
+    m_pColourpage = new QWidget(m_pTabselect, "Colourpage");
+    m_pColourlayout = new QHBoxLayout(m_pColourpage, 11, 6, "Colourlayout");
+    m_pShadebox = new QGroupBox(m_pColourpage, "Shadegroupbox");
+    m_pShadebox->setColumnLayout(0, Qt::Horizontal);
+    m_pShadebox->layout()->setSpacing(6);
+    m_pShadebox->layout()->setMargin(11);
+    m_pShadeboxlay = new QVBoxLayout(m_pShadebox->layout());
+    m_pShadeboxlay->setAlignment(Qt::AlignTop);
+
+    m_pShadelayout = new QGridLayout(0, 2, 2, 6, 16, "Shadelayout");
+    m_pLightlab = new QLabel(m_pShadebox, "Lightlabel");
+    m_pLightlab->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred, this->sizePolicy().hasHeightForWidth());
+    m_pShadelayout->addWidget(m_pLightlab, 0, 0);
+    m_pLightbutt = new QToolButton(m_pShadebox, "Lightbutton");
+    m_pLightbutt->setFocusPolicy(QToolButton::TabFocus);
+    m_pLightbutt->setCursor(QCursor(13));
+    m_pShadelayout->addWidget(m_pLightbutt, 0, 1);
+
+    m_pDarklab = new QLabel(m_pShadebox, "Darklabel");
+    m_pDarklab->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred, this->sizePolicy().hasHeightForWidth());
+    m_pShadelayout->addWidget(m_pDarklab, 1, 0);
+    m_pDarkbutt = new QToolButton(m_pShadebox, "Darkbutton");
+    m_pDarkbutt->setFocusPolicy(QToolButton::TabFocus);
+    m_pDarkbutt->setCursor(QCursor(13));
+    m_pShadelayout->addWidget(m_pDarkbutt, 1, 1);
+
+    m_pRevertlab = new QLabel(m_pShadebox, "Revertlabel");
+    m_pShadelayout->addWidget(m_pRevertlab, 2, 0);
+    m_pRevertbutt = new QToolButton(m_pShadebox, "Revertbutton");
+    m_pRevertbutt->setFocusPolicy(QToolButton::TabFocus);
+//    m_pRevertbutt->setIconSet(QIconSet(QPixmap(s_kpcRevcolour_xpm)));
+    m_pRevertbutt->setCursor(QCursor(13));
+    m_pShadelayout->addWidget(m_pRevertbutt, 2, 1);
+
+    m_pThemebox = new QGroupBox(m_pColourpage, "Themegroupbox");
+    m_pThemebox->setColumnLayout(0, Qt::Vertical);
+    m_pThemebox->layout()->setSpacing(6);
+    m_pThemebox->layout()->setMargin(11);
+    m_pThemeboxlay = new QVBoxLayout(m_pThemebox->layout());
+
+    QLabel *pPlaceholder = new QLabel(m_pThemebox, "Placeholderlabel");
+    pPlaceholder->setText(trUtf8("Reserved for future use", "Comment for Placeholderlabel"));
+    m_pThemeboxlay->addWidget(pPlaceholder, 1, Qt::AlignCenter);
+
+    m_pShadeboxlay->addLayout(m_pShadelayout);
+    m_pColourlayout->addWidget(m_pShadebox);
+    m_pColourlayout->addWidget(m_pThemebox);
+    m_pTabselect->insertTab(m_pColourpage, "");
+
+    connect(m_pLightbutt, SIGNAL(clicked(void)), SLOT(shadeLight(void)));
+    connect(m_pDarkbutt, SIGNAL(clicked(void)), SLOT(shadeDark(void)));
+    connect(m_pRevertbutt, SIGNAL(clicked(void)), SLOT(shadeRevert(void)));
+
     // Finally add the damn pages to the tab selector widget!
     m_pVlayout->addWidget(m_pTabselect);
 
@@ -243,54 +302,119 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     this->resize(QSize(400, 264).expandedTo(minimumSizeHint()));
 }
 
+//
+// Sets the light shading colour for rows
+//
+void Prefpanel::shadeLight(void)
+{
+    QColorDialog::setCustomColor(0, m_pLight->rgb());
+    QColorDialog::setCustomColor(1, m_pDark->rgb());
+    QColor Colortemp = QColorDialog::getColor(*m_pLight);
+    if (Colortemp.isValid()) {
+        delete m_pLight;
+        m_pLight = new QColor(Colortemp);
+        m_pLightbutt->setPaletteBackgroundColor(*m_pLight);
+    }
+}
+
+//
+// Sets the dark shading colour for rows
+//
+void Prefpanel::shadeDark(void)
+{
+    QColorDialog::setCustomColor(0, m_pLight->rgb());
+    QColorDialog::setCustomColor(1, m_pDark->rgb());
+    QColor Colortemp = QColorDialog::getColor(*m_pDark);
+    if (Colortemp.isValid()) {
+        delete m_pDark;
+        m_pDark = new QColor(Colortemp);
+        m_pDarkbutt->setPaletteBackgroundColor(*m_pDark);
+    }
+}
+
+//
+// Reverts the shading colours to default values
+//
+void Prefpanel::shadeRevert(void)
+{
+    delete m_pLight;
+    m_pLight = new QColor(*this->getRevlight());
+    m_pLightbutt->setPaletteBackgroundColor(*m_pLight);
+    delete m_pDark;
+    m_pDark = new QColor(*this->getRevdark());
+    m_pDarkbutt->setPaletteBackgroundColor(*m_pDark);
+}
+
+//
+// Polish off ending changes after creating and before widget shows
+//
+void Prefpanel::polish(void)
+{
+    // Set our buttons now that user has probably set their colours
+    m_pLightbutt->setPaletteBackgroundColor(*m_pLight);
+    m_pDarkbutt->setPaletteBackgroundColor(*m_pDark);
+}
+
 //
 // Sets the strings of the subwidgets using the current language
 //
 void Prefpanel::textChange(void)
 {
-    this->setCaption(tr("AS Applicate Preferences", "Personal preferences are persistent across sessions"));
+    this->setCaption(trUtf8("AS Applicate Preferences", "Personal preferences are persistent across sessions"));
 
-    m_pTabselect->changeTab(m_pBoolpage, tr("General"));
-    m_pTabselect->changeTab(m_pGeneralpage, tr("Paths"));
-    m_pTabselect->changeTab(m_pRemotepage, tr("Hosts"));
+    m_pTabselect->changeTab(m_pBoolpage, trUtf8("General"));
+    m_pTabselect->changeTab(m_pGeneralpage, trUtf8("Paths"));
+    m_pTabselect->changeTab(m_pRemotepage, trUtf8("Hosts"));
+    m_pTabselect->changeTab(m_pColourpage, trUtf8("Colour"));
 
-    m_pOkaybutton->setText(tr("Okay", "Comment for Okaybutton"));
-    QToolTip::add(m_pOkaybutton, tr("Applies and saves changes", "Comment for tooltip Okaybutton"));
-    QWhatsThis::add(m_pOkaybutton, tr("The okay button applies and saves changes", "Comment for whatsThis Okaybutton"));
+    m_pOkaybutton->setText(trUtf8("Okay", "Comment for Okaybutton"));
+    QToolTip::add(m_pOkaybutton, trUtf8("Applies and saves changes", "Comment for tooltip Okaybutton"));
+    QWhatsThis::add(m_pOkaybutton, trUtf8("The okay button applies and saves changes", "Comment for whatsThis Okaybutton"));
 
-    m_pApplybutton->setText(tr("Apply", "Comment for Applybutton"));
-    QToolTip::add(m_pApplybutton, tr("Apply changes immediately", "Comment for toolTip Applybutton"));
-    QWhatsThis::add(m_pApplybutton, tr("The apply button applies changes immediately", "Comment for whatsThis Applybutton"));
+    m_pApplybutton->setText(trUtf8("Apply", "Comment for Applybutton"));
+    QToolTip::add(m_pApplybutton, trUtf8("Apply changes immediately", "Comment for toolTip Applybutton"));
+    QWhatsThis::add(m_pApplybutton, trUtf8("The apply button applies changes immediately", "Comment for whatsThis Applybutton"));
 
-    m_pCancelbutton->setText(tr("Cancel", "Comment for Cancelbutton"));
-    QToolTip::add(m_pCancelbutton, tr("Cancel any changes", "Comment for toolTip Cancelbutton"));
-    QWhatsThis::add(m_pCancelbutton, tr("The cancel button cancels any changes", "Comment for whatsThis Cancelbutton"));
+    m_pCancelbutton->setText(trUtf8("Cancel", "Comment for Cancelbutton"));
+    QToolTip::add(m_pCancelbutton, trUtf8("Cancel any changes", "Comment for toolTip Cancelbutton"));
+    QWhatsThis::add(m_pCancelbutton, trUtf8("The cancel button cancels any changes", "Comment for whatsThis Cancelbutton"));
 
-    m_pGenbox->setTitle(tr("File and directory paths", "Comment for Genbox"));
-    m_pAcctlabel->setText(tr("Accounts path", "Comment for Acctlabel"));
-    m_pEventlabel->setText(tr("Events directory", "Comment for Eventlabel"));
-    m_pUserlabel->setText(tr("User name", "Comment for Userlabel"));
-    m_pHomelabel->setText(tr("Home directory", "Comment for Homelabel"));
-    QToolTip::add(m_pAcctline, tr("The accounts file pathname", "Comment for toolTip Acctline"));
-    QToolTip::add(m_pEventline, tr("The default events directory", "Comment for toolTip Eventline"));
-    QToolTip::add(m_pUserline, tr("The user name", "Comment for toolTip Userline"));
-    QToolTip::add(m_pHomeline, tr("The home directory", "Comment for toolTip Homeline"));
+    m_pGenbox->setTitle(trUtf8("File and directory paths", "Comment for Genbox"));
+    m_pAcctlabel->setText(trUtf8("Accounts path", "Comment for Acctlabel"));
+    m_pEventlabel->setText(trUtf8("Events directory", "Comment for Eventlabel"));
+    m_pUserlabel->setText(trUtf8("User name", "Comment for Userlabel"));
+    m_pHomelabel->setText(trUtf8("Home directory", "Comment for Homelabel"));
+    QToolTip::add(m_pAcctline, trUtf8("The accounts file pathname", "Comment for toolTip Acctline"));
+    QToolTip::add(m_pEventline, trUtf8("The default events directory", "Comment for toolTip Eventline"));
+    QToolTip::add(m_pUserline, trUtf8("The user name", "Comment for toolTip Userline"));
+    QToolTip::add(m_pHomeline, trUtf8("The home directory", "Comment for toolTip Homeline"));
 
-    m_pRembox->setTitle(tr("Remote host names", "Comment for Rembox"));
-    m_pCorbalabel->setText(tr("CORBA host", "Comment for Corbalabel"));
-    m_pSoaplabel->setText(tr("SOAP host", "Comment for Soaplabel"));
-    QToolTip::add(m_pCorbaline, tr("The CORBA host name", "Comment for toolTip Corbaline"));
-    QToolTip::add(m_pSoapline, tr("The SOAP host name", "Comment for toolTip Soapline"));
+    m_pRembox->setTitle(trUtf8("Remote host names", "Comment for Rembox"));
+    m_pCorbalabel->setText(trUtf8("CORBA host", "Comment for Corbalabel"));
+    m_pSoaplabel->setText(trUtf8("SOAP host", "Comment for Soaplabel"));
+    QToolTip::add(m_pCorbaline, trUtf8("The CORBA host name", "Comment for toolTip Corbaline"));
+    QToolTip::add(m_pSoapline, trUtf8("The SOAP host name", "Comment for toolTip Soapline"));
 
-    m_pCorbacheck->setText(tr("Enable IIOP transmission", "Comment for Corbacheck"));
-    QToolTip::add(m_pCorbacheck, tr("Will enable transmission over IIOP", "Comment for toolTip Corbacheck"));
-    QWhatsThis::add(m_pCorbacheck, tr("Check this box to enable transmission to a CORBA host", "Comment whatsThis for Corbacheck"));
+    m_pCorbacheck->setText(trUtf8("Enable IIOP transmission", "Comment for Corbacheck"));
+    QToolTip::add(m_pCorbacheck, trUtf8("Will enable transmission over IIOP", "Comment for toolTip Corbacheck"));
+    QWhatsThis::add(m_pCorbacheck, trUtf8("Check this box to enable transmission to a CORBA host", "Comment whatsThis for Corbacheck"));
 
-    m_pSoapcheck->setText(tr("Enable SOAP transmission", "Comment for Soapcheck"));
-    QToolTip::add(m_pSoapcheck, tr("Will enable transmission over SOAP", "Comment for toolTip Soapcheck"));
-    QWhatsThis::add(m_pSoapcheck, tr("Check this box to enable transmission over to a SOAP host", "Comment whatsThis for Soapcheck"));
+    m_pSoapcheck->setText(trUtf8("Enable SOAP transmission", "Comment for Soapcheck"));
+    QToolTip::add(m_pSoapcheck, trUtf8("Will enable transmission over SOAP", "Comment for toolTip Soapcheck"));
+    QWhatsThis::add(m_pSoapcheck, trUtf8("Check this box to enable transmission to a SOAP host", "Comment whatsThis for Soapcheck"));
 
-    m_pStylegroup->setTitle(tr("Available styles", "Comment for Stylebuttons"));
-    m_pReportgroup->setTitle(tr("Report options", "Comment for Reportbox"));
-    m_pSwitchgroup->setTitle(tr("Other options", "Comment for Switchbox"));
+    m_pShadebox->setTitle(trUtf8("Row shading", "Comment for Shadebox"));
+    m_pThemebox->setTitle(trUtf8("Skin themes", "Comment for Themebox"));
+
+    m_pLightlab->setText(trUtf8("Light", "Comment for Lightlabel"));
+    m_pDarklab->setText(trUtf8("Dark", "Comment for Darklabel"));
+    m_pRevertlab->setText(trUtf8("Revert", "Comment for Revertlabel"));
+    QToolTip::add(m_pLightbutt, trUtf8("Light row shading colour", "Comment for tooltip Lightbutt"));
+    QWhatsThis::add(m_pLightbutt, trUtf8("The Light button sets the light row shading colour.", "Comment for whatsThis Lightbutt"));
+    QToolTip::add(m_pDarkbutt, trUtf8("Dark row shading colour", "Comment for tooltip Darkbutt"));
+    QWhatsThis::add(m_pDarkbutt, trUtf8("The Dark button sets the light row shading colour.", "Comment for whatsThis Darkbutt"));
+
+    m_pStylegroup->setTitle(trUtf8("Available styles", "Comment for Stylebuttons"));
+    m_pReportgroup->setTitle(trUtf8("Report options", "Comment for Reportbox"));
+    m_pSwitchgroup->setTitle(trUtf8("Other options", "Comment for Switchbox"));
 }
