@@ -38,6 +38,8 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
+#include <qtoolbutton.h>
+#include <qcolordialog.h>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
 #include <qtabwidget.h>
@@ -48,7 +50,7 @@
 #include <qstylefactory.h>
 #include <qlayout.h>
 
-#include "as_gui.h" // For usage of style_t
+#include "as_gui.h"     // For usage of style_t
 
 
 class Prefpanel : public QDialog
@@ -59,14 +61,21 @@ public:
     Prefpanel(QWidget *pParent = 0, const char *kszName = 0, bool bModal = true, WFlags Flags = 0);
 //    ~Prefpanel(void); // No need to destroy widgets, because qt does it for us
 
-    QGroupBox *m_pGenbox, *m_pRembox;
+private:
+    Preferences *m_pPanprefs;
+    QColor *m_pLight, *m_pDark;
+    QColorGroup *m_pOrigcolours;
+
+public:
+    QGroupBox *m_pGenbox, *m_pRembox, *m_pShadebox, *m_pThemebox;
     QVBoxLayout *m_pStylelay, *m_pReportlay, *m_pSwitchlay;
     QVBoxLayout *m_pVlayout, *m_pBinlayout;
     QHBoxLayout *m_pBoolayout, *m_pGenlayout, *m_pRemlayout;
-    QHBoxLayout *m_pGenboxlay, *m_pRemboxlay;
-    QGridLayout *m_pGeninner, *m_pReminner;
+    QVBoxLayout *m_pShadeboxlay, *m_pThemeboxlay;
+    QHBoxLayout *m_pGenboxlay, *m_pRemboxlay, *m_pColourlayout;
+    QGridLayout *m_pGeninner, *m_pReminner, *m_pShadelayout;
 
-    QWidget *m_pBoolpage, *m_pGeneralpage, *m_pRemotepage;
+    QWidget *m_pBoolpage, *m_pGeneralpage, *m_pRemotepage, *m_pColourpage;
 
     QHBoxLayout *m_pButtlay;
     QPushButton *m_pOkaybutton;
@@ -82,6 +91,9 @@ public:
     QLineEdit *m_pCorbaline, *m_pSoapline;
     QCheckBox *m_pCorbacheck, *m_pSoapcheck;
 
+    QLabel *m_pLightlab, *m_pDarklab, *m_pRevertlab;
+    QToolButton *m_pLightbutt, *m_pDarkbutt, *m_pRevertbutt;
+
     QButtonGroup *m_pStylegroup, *m_pReportgroup, *m_pSwitchgroup;
     QCheckBox *m_pBackupcheck, *m_pExtendcheck;
     QCheckBox *m_pDetailcheck, *m_pSigncheck;
@@ -99,6 +111,12 @@ public:
     bool getSoapon(void)       {return (m_pSoapcheck->isChecked());};
     bool getBackon(void)       {return (m_pBackupcheck->isChecked());};
     bool getExtendon(void)     {return (m_pExtendcheck->isChecked());};
+    bool getDetailon(void)     {return (m_pDetailcheck->isChecked());};
+    bool getSignaton(void)     {return (m_pSigncheck->isChecked());};
+    QColor *getLight(void)     {return m_pLight;};
+    QColor *getDark(void)      {return m_pDark;};
+    QColor *getRevlight(void)  {return (QColor *)&m_pOrigcolours->foreground();};
+    QColor *getRevdark(void)   {return (QColor *)&m_pOrigcolours->background();};
 
     // Accessor set methods
     void setAccounts(const QString &kInstr)  {m_pAcctline->setText(kInstr);};
@@ -109,9 +127,14 @@ public:
     void setSoaphost(const QString &kInstr)  {m_pSoapline->setText(kInstr);};
     void setBackon(const bool &kbEnable = true)   {m_pBackupcheck->setChecked(kbEnable);};
     void setExtendon(const bool &kbEnable = true) {m_pExtendcheck->setChecked(kbEnable);};
-    void lockCorba(const bool &kbLock = true) {m_pCorbacheck->setEnabled(!kbLock);};
-    void lockSoap(const bool &kbLock = true) {m_pSoapcheck->setEnabled(!kbLock);};
-    void setCorbaon(const bool &kbEnable = true) {
+    void setDetailon(const bool &kbEnable = true) {m_pDetailcheck->setChecked(kbEnable);};
+    void setSignaton(const bool &kbEnable = true) {m_pSigncheck->setChecked(kbEnable);};
+    void lockCorba(const bool &kbLock = true)     {m_pCorbacheck->setEnabled(!kbLock);};
+    void lockSoap(const bool &kbLock = true)      {m_pSoapcheck->setEnabled(!kbLock);};
+    void setLight(const QColor *pLight)           {m_pLight = (QColor *)pLight;};
+    void setDark(const QColor *pDark)             {m_pDark = (QColor *)pDark;};
+    void setOrigcolour(QColorGroup *pGroup)       {m_pOrigcolours = pGroup;};
+    void setCorbaon(const bool &kbEnable = true)  {
         m_pCorbaline->setEnabled(kbEnable);
         m_pCorbacheck->setChecked(kbEnable);
     };
@@ -126,7 +149,11 @@ public:
     };
 
 protected slots:
+    virtual void polish(void);
     virtual void textChange(void);
+    virtual void shadeLight(void);
+    virtual void shadeDark(void);
+    virtual void shadeRevert(void);
     void enableCorba(bool bOn) {m_pCorbaline->setEnabled(bOn);};
     void enableSoap(bool bOn) {m_pSoapline->setEnabled(bOn);};
 
