@@ -77,7 +77,7 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     // Make Panel resizeable
     this->setSizeGripEnabled(true);
     this->setSizePolicy(QSizePolicy((QSizePolicy::SizeType)5,
-        (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth()));
+        (QSizePolicy::SizeType)5, 0, 0, this->sizePolicy().hasHeightForWidth()));
 
     // Store matrix and prefs members
     m_pReptable = pTable;
@@ -128,11 +128,11 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     m_pWeekpop = new QPopupMenu(this);
     if (m_pWeekpop == NULL) // Sanity check
         throw Genexcept("Weekly toolbutton popup creation failed.");
-    m_pWeekpop->insertItem(tr("One week"), this, SLOT(reportWeeks(int)));
-    m_pWeekpop->insertItem(tr("Two weeks"), this, SLOT(reportWeeks(int)));
-    m_pWeekpop->insertItem(tr("Three weeks"), this, SLOT(reportWeeks(int)));
-    m_pWeekpop->insertItem(tr("Four weeks"), this, SLOT(reportWeeks(int)));
-    m_pWeekpop->insertItem(tr("N... weeks"), this, SLOT(reportWeeks(int)));
+    m_pWeekpop->insertItem(trUtf8("One week"), this, SLOT(reportWeeks(int)));
+    m_pWeekpop->insertItem(trUtf8("Two weeks"), this, SLOT(reportWeeks(int)));
+    m_pWeekpop->insertItem(trUtf8("Three weeks"), this, SLOT(reportWeeks(int)));
+    m_pWeekpop->insertItem(trUtf8("Four weeks"), this, SLOT(reportWeeks(int)));
+    m_pWeekpop->insertItem(trUtf8("N... weeks"), this, SLOT(reportWeeks(int)));
     m_pWeekpop->setCheckable(true);
     m_pWeekpop->setItemChecked(m_pWeekpop->idAt(m_nWeeks - 1), true);
     m_pWeeklybutt->setPopup(m_pWeekpop);
@@ -142,11 +142,11 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     m_pMonthpop = new QPopupMenu(this);
     if (m_pMonthpop == NULL) // Sanity check
         throw Genexcept("Monthly toolbutton popup creation failed.");
-    m_pMonthpop->insertItem(tr("One month"), this, SLOT(reportMonths(int)));
-    m_pMonthpop->insertItem(tr("Two months"), this, SLOT(reportMonths(int)));
-    m_pMonthpop->insertItem(tr("Three months"), this, SLOT(reportMonths(int)));
-    m_pMonthpop->insertItem(tr("Four months"), this, SLOT(reportMonths(int)));
-    m_pMonthpop->insertItem(tr("N... months"), this, SLOT(reportMonths(int)));
+    m_pMonthpop->insertItem(trUtf8("One month"), this, SLOT(reportMonths(int)));
+    m_pMonthpop->insertItem(trUtf8("Two months"), this, SLOT(reportMonths(int)));
+    m_pMonthpop->insertItem(trUtf8("Three months"), this, SLOT(reportMonths(int)));
+    m_pMonthpop->insertItem(trUtf8("Four months"), this, SLOT(reportMonths(int)));
+    m_pMonthpop->insertItem(trUtf8("N... months"), this, SLOT(reportMonths(int)));
     m_pMonthpop->setCheckable(true);
     m_pMonthpop->setItemChecked(m_pMonthpop->idAt(m_nMonths - 1), true);
     m_pMonthlybutt->setPopup(m_pMonthpop);
@@ -257,8 +257,9 @@ void Reportpanel::reportWeeks(int nMenuid)
         this->writeHeader(nLastweek);
 
     // Write new contents to data window
-    for (int nIter = 0; nIter < m_nWeeks; nIter++)
-        m_pBrowser->append(this->getWeek(QDate::currentDate().addDays(nIter * -7)));
+    m_pBrowser->append(this->getWeektotals(QDate::currentDate(), m_nWeeks));
+    if (m_pReprefs->getBool(TITRAQ_PREFDETAILON, TITRAQ_DEFDETAILON))
+        m_pBrowser->append(this->getWeekdetails(QDate::currentDate(), m_nWeeks));
     this->writeFooter();
     m_pBrowser->setCursorPosition(0, 0);
     m_pBrowser->ensureCursorVisible();
@@ -309,8 +310,10 @@ void Reportpanel::reportMonths(int nMenuid)
         this->writeHeader(Lastmonth);
 
     // Write new contents to data window
-    for (int nIter = 0; nIter < m_nMonths; nIter++)
-        m_pBrowser->append(this->getMonth(QDate::currentDate().addMonths(nIter * -1)));
+    m_pBrowser->append(this->getMonthtotals(QDate::currentDate(), m_nMonths));
+    if (m_pReprefs->getBool(TITRAQ_PREFDETAILON, TITRAQ_DEFDETAILON)) {
+        m_pBrowser->append(this->getMonthdetails(QDate::currentDate(), m_nMonths));
+    }
     this->writeFooter();
     m_pBrowser->setCursorPosition(0, 0);
     m_pBrowser->ensureCursorVisible();
@@ -326,15 +329,8 @@ void Reportpanel::reportBoth(int nMenuid)
     // Set the button in case we arrived from a menu selection
     m_pWeekmonthgroup->setButton(TITRAQ_REPORTBOTH);
 
-    // Clear data window and write header out
-    m_pBrowser->setUpdatesEnabled(false);
-    m_pBrowser->clear();
-    m_pBrowser->append(tr("The 'both' feature is not working yet."));
-    this->writeFooter();
-    m_pBrowser->setCursorPosition(0, 0);
-    m_pBrowser->ensureCursorVisible();
-    m_pBrowser->setUpdatesEnabled(true);
-    m_pBrowser->repaint(false);
+    // Placeholder text until we figure out what to do with this
+    m_pBrowser->setText(trUtf8("The 'both' feature is not working yet."));
 }
 
 //
@@ -354,8 +350,6 @@ void Reportpanel::writeHeader(int nWeeknum)
     Header += QTime::currentTime().toString(Qt::ISODate);
     Header += trUtf8("\nReporting for week %1...").arg(nWeeknum);
     Header += QString("\n\n");
-    Header += QString("Date       Hours Task\n");
-    Header += QString("---------- ----- ----\n");
     m_pBrowser->setText(Header);
 }
 
@@ -376,8 +370,6 @@ void Reportpanel::writeHeader(QString Month)
     Header += QTime::currentTime().toString(Qt::ISODate);
     Header += trUtf8("\nReporting for month %1...").arg(Month);
     Header += QString("\n\n");
-    Header += QString("Date       Hours Task\n");
-    Header += QString("---------- ----- ----\n");
     m_pBrowser->setText(Header);
 }
 
@@ -398,8 +390,6 @@ void Reportpanel::writeHeader(int nFirst, int nLast)
     Header += QTime::currentTime().toString(Qt::ISODate);
     Header += trUtf8("\nReporting for weeks %1 through %2...").arg(nFirst).arg(nLast);
     Header += QString("\n\n");
-    Header += QString("Date       Hours Task\n");
-    Header += QString("---------- ----- ----\n");
     m_pBrowser->setText(Header);
 }
 
@@ -420,8 +410,6 @@ void Reportpanel::writeHeader(QString First, QString Last)
     Header += QTime::currentTime().toString(Qt::ISODate);
     Header += trUtf8("\nReporting months %1 through %2...").arg(First).arg(Last);
     Header += QString("\n\n");
-    Header += QString("Date       Hours Task\n");
-    Header += QString("---------- ----- ----\n");
     m_pBrowser->setText(Header);
 }
 
@@ -430,20 +418,151 @@ void Reportpanel::writeHeader(QString First, QString Last)
 //
 void Reportpanel::writeFooter(void)
 {
+    if (m_pReprefs->getBool(TITRAQ_PREFSIGNATON, TITRAQ_DEFSIGNATON)) {
+        m_pBrowser->append(trUtf8("\n\nPrint name ________________________________________\n"));
+        m_pBrowser->append(trUtf8("\n\nSignature  ________________________________________"));
+    }
 }
 
 //
-// Writes one week of data to the display window
+// Returns one week of details data
 //
-QString Reportpanel::getWeek(QDate Dayref)
+QString Reportpanel::getWeekdetails(QDate Dayref, int nWeeks)
 {
     QString Data, Tempstring; // Output string
     int nRows      = m_pReptable->numRows();
     int nIter      = nRows - 1;
     int nFirstrow  = 0;
     int nLastrow   = 0;
-    QDate Firstday = Dayref.addDays(Dayref.dayOfWeek() * -1 + 1);   // Do negate
-    QDate Lastday  = Firstday.addDays(7);                           // Add week
+
+    Q_ASSERT(nWeeks > 0);
+    QDate Firstday;
+    QDate Lastday;
+    Firstday = Dayref.addDays(Dayref.dayOfWeek() * -1 + 1);
+    Firstday = Firstday.addDays((nWeeks - 1) * -7);
+    Lastday  = Firstday.addDays(7 * nWeeks);
+
+    // Write some quick header text to the outgoing string
+    Data  = trUtf8("\nDate       Hours Account details\n");
+    Data += QString("---------- ----- ----------------------------------------\n");
+
+    // Find data starting the week in question
+    while (QDate::fromString(m_pReptable->text(nIter, TITRAQ_IDXDATE), Qt::ISODate) >= Firstday)
+        nIter--;
+    nFirstrow = ++nIter; // The first row to operate on
+
+    // Find data ending the week in question
+    while (nIter < nRows && QDate::fromString(m_pReptable->text(nIter, TITRAQ_IDXDATE), Qt::ISODate) <  Lastday)
+        nIter++;
+    nLastrow = nIter - 1; // The last row to operate on
+
+    // Build the long week data string
+    for (nIter = nLastrow; nIter >= nFirstrow; nIter--) {
+        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXDATE);
+        if (!Tempstring.isEmpty())
+            Data += Tempstring;
+        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXAMOUNT);
+        if (!Tempstring.isEmpty())
+            Data += QString(TITRAQ_SEPARATORTOK) + Tempstring;
+        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXTASK);
+        if (!Tempstring.isEmpty())
+            Data += QString(TITRAQ_SEPARATORTOK) + Tempstring;
+        Data += QString("\n"); // Finish off line
+    }
+
+    return Data;
+}
+
+//
+// Returns one week of totals data
+//
+QString Reportpanel::getWeektotals(QDate Dayref, int nWeeks)
+{
+    using namespace std;                    // Needed for hash tables with hmap
+    map<string, string> Hashtasks;          // Hashtable for storing tasks
+    map<string, string> Hashhours;          // Hashtable for storing hours
+    map<string, string>::iterator Taskiter; // The hashtable task iterator
+    map<string, string>::iterator Houriter; // The hashtable hour iterator
+
+    QString Totals;                         // Data totals to return for writing
+    QString Tempstring;                     // Temporary processing string
+    int nRows      = m_pReptable->numRows();
+    int nIter      = nRows - 1;
+    int nFirstrow  = 0;
+    int nLastrow   = 0;
+
+    Q_ASSERT(nWeeks > 0);
+    QDate Firstday;
+    QDate Lastday;
+    Firstday = Dayref.addDays(Dayref.dayOfWeek() * -1 + 1);
+    Firstday = Firstday.addDays((nWeeks - 1) * -7);
+    Lastday  = Firstday.addDays(7 * nWeeks);
+
+    // Find data starting the week in question
+    while (QDate::fromString(m_pReptable->text(nIter, TITRAQ_IDXDATE), Qt::ISODate) >= Firstday)
+        nIter--;
+    nFirstrow = ++nIter; // The first row to operate on
+
+    // Find data ending the week in question
+    while (nIter < nRows && QDate::fromString(m_pReptable->text(nIter, TITRAQ_IDXDATE), Qt::ISODate) <  Lastday)
+        nIter++;
+    nLastrow = nIter - 1; // The last row to operate on
+
+    // Parse the table for interesting values
+    for (nIter = nLastrow; nIter >= nFirstrow; nIter--) {
+        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXTASK);
+        if (!Tempstring.isEmpty()) {
+            string Convstring = Tempstring;         // Convert to string (can't cast?)
+            QTime Intable = QTime::fromString(m_pReptable->text(nIter, TITRAQ_IDXAMOUNT), Qt::ISODate);
+            int nTothours = QString(Hashtasks[Convstring]).section(':', 0, 0).toInt() + Intable.hour();
+            int nTotminut = QString(Hashtasks[Convstring]).section(':', 1, 1).toInt() + Intable.minute();
+            nTothours += nTotminut / 60;
+            nTotminut %= 60;
+            QString Hours = QString::number(nTothours).rightJustify(3, ' ');
+            QString Mins  = QString::number(nTotminut).rightJustify(2, '0');
+            string Timestring = Hours + ':' + Mins; // Convert to string (can't cast?)
+            Hashtasks[Convstring] = Timestring;     // Finally store in hashtable
+        }
+    }
+
+    // Reverse copy the tasks hashtable to both sort and index by amount key
+    for (Taskiter = Hashtasks.begin(); Taskiter != Hashtasks.end(); Taskiter++)
+        Hashhours[Taskiter->second] = Taskiter->first;
+
+    // Write the actual data totals to the outgoing string in reverse order
+    for (Houriter = Hashhours.begin(); Houriter != Hashhours.end(); Houriter++)
+        Totals = Houriter->first + ' ' + Houriter->second + '\n' + Totals;
+
+    // Write some quick header text to the outgoing string in reverse order
+    Totals = QString("------ ----------------------------------------\n") + Totals;
+    Totals = trUtf8("Total  Account summary\n") + Totals;
+
+    return Totals; // The outgoing string... its finally gone, let's go to bed
+}
+
+//
+// Returns one month of details data
+//
+QString Reportpanel::getMonthdetails(QDate Dayref, int nMonths)
+{
+    QString Data, Tempstring; // Output string
+    int nRows      = m_pReptable->numRows();
+    int nIter      = nRows - 1;
+    int nFirstrow  = 0;
+    int nLastrow   = 0;
+
+    // Find range boundaries
+    Q_ASSERT(nMonths > 0);
+    int nYear = Dayref.year();
+    int nMonth = (Dayref.addMonths(nMonths * -1).month() + 12) % 12 + 1;
+    if (nMonth > Dayref.month())
+        nYear--;
+    QDate Firstday = QDate(nYear, nMonth, 1);
+    QDate Lastday  = QDate(Dayref.year(), Dayref.month(), Dayref.daysInMonth());
+
+    // Write some quick header text to the outgoing string
+    Data  = trUtf8("\nDate       Hours Account details\n");
+    Data += QString("---------- ----- ----------------------------------------\n");
 
     // Find data starting the week in question
     while (QDate::fromString(m_pReptable->text(nIter, TITRAQ_IDXDATE), Qt::ISODate) >= Firstday)
@@ -473,16 +592,30 @@ QString Reportpanel::getWeek(QDate Dayref)
 }
 
 //
-// Writes one month of data to the display window
+// Returns one month of totals data
 //
-QString Reportpanel::getMonth(QDate Dayref)
+QString Reportpanel::getMonthtotals(QDate Dayref, int nMonths)
 {
-    QString Data, Tempstring; // Output string
+    using namespace std;                    // Needed for hash tables with hmap
+    map<string, string> Hashtasks;          // Hashtable for storing tasks
+    map<string, string> Hashhours;          // Hashtable for storing hours
+    map<string, string>::iterator Taskiter; // The hashtable task iterator
+    map<string, string>::iterator Houriter; // The hashtable hour iterator
+
+    QString Totals;                         // Data totals to return for writing
+    QString Tempstring;                     // Temporary processing string
     int nRows      = m_pReptable->numRows();
     int nIter      = nRows - 1;
     int nFirstrow  = 0;
     int nLastrow   = 0;
-    QDate Firstday = QDate(Dayref.year(), Dayref.month(), 1);
+
+    // Find range boundaries
+    Q_ASSERT(nMonths > 0);
+    int nYear = Dayref.year();
+    int nMonth = (Dayref.addMonths(nMonths * -1).month() + 12) % 12 + 1;
+    if (nMonth > Dayref.month())
+        nYear--;
+    QDate Firstday = QDate(nYear, nMonth, 1);
     QDate Lastday  = QDate(Dayref.year(), Dayref.month(), Dayref.daysInMonth());
 
     // Find data starting the week in question
@@ -495,21 +628,36 @@ QString Reportpanel::getMonth(QDate Dayref)
         nIter++;
     nLastrow = nIter - 1; // The last row to operate on
 
-    // Build the long week data string
+    // Parse the table for interesting values
     for (nIter = nLastrow; nIter >= nFirstrow; nIter--) {
-        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXDATE);
-        if (!Tempstring.isEmpty())
-            Data += Tempstring;
-        Tempstring = m_pReptable->text(nIter, TITRAQ_IDXAMOUNT);
-        if (!Tempstring.isEmpty())
-            Data += QString(TITRAQ_SEPARATORTOK) + Tempstring;
         Tempstring = m_pReptable->text(nIter, TITRAQ_IDXTASK);
-        if (!Tempstring.isEmpty())
-            Data += QString(TITRAQ_SEPARATORTOK) + Tempstring;
-        Data += trUtf8("\n"); // Finish off line
+        if (!Tempstring.isEmpty()) {
+            string Convstring = Tempstring;         // Convert to string (can't cast?)
+            QTime Intable = QTime::fromString(m_pReptable->text(nIter, TITRAQ_IDXAMOUNT), Qt::ISODate);
+            int nTothours = QString(Hashtasks[Convstring]).section(':', 0, 0).toInt() + Intable.hour();
+            int nTotminut = QString(Hashtasks[Convstring]).section(':', 1, 1).toInt() + Intable.minute();
+            nTothours += nTotminut / 60;
+            nTotminut %= 60;
+            QString Hours = QString::number(nTothours).rightJustify(3, ' ');
+            QString Mins  = QString::number(nTotminut).rightJustify(2, '0');
+            string Timestring = Hours + ':' + Mins; // Convert to string (can't cast?)
+            Hashtasks[Convstring] = Timestring;     // Finally store in hashtable
+        }
     }
 
-    return Data;
+    // Reverse copy the tasks hashtable to both sort and index by amount key
+    for (Taskiter = Hashtasks.begin(); Taskiter != Hashtasks.end(); Taskiter++)
+        Hashhours[Taskiter->second] = Taskiter->first;
+
+    // Write the actual data totals to the outgoing string in reverse order
+    for (Houriter = Hashhours.begin(); Houriter != Hashhours.end(); Houriter++)
+        Totals = Houriter->first + ' ' + Houriter->second + '\n' + Totals;
+
+    // Write some quick header text to the outgoing string in reverse order
+    Totals = QString("------ ----------------------------------------\n") + Totals;
+    Totals = trUtf8("Total  Account summary\n") + Totals;
+
+    return Totals; // The outgoing string... its finally gone, let's go to bed
 }
 
 //
@@ -543,7 +691,6 @@ void Reportpanel::saveReport(void)
             QTextStream Outstream(&Report);             // Convert to stream
             Outstream << m_pBrowser->text();            // Write the data
             Report.close();                             // Finish by closing
-qDebug(m_pBrowser->text().ascii());
         }
     }
     // Otherwise, user did not select a valid file and push okay button
@@ -554,25 +701,25 @@ qDebug(m_pBrowser->text().ascii());
 //
 void Reportpanel::textChange(void)
 {
-    this->setCaption(tr("AS local report", "Local report using weekly data or monthly data or both."));
+    this->setCaption(trUtf8("AS local report", "Local report using weekly data or monthly data or both."));
 
     // Top level push buttons associated with accept and save slots
-    m_pDismissbutt->setText(tr("Dismiss", "Comment for Dismissbutton"));
-    QToolTip::add(m_pDismissbutt, tr("Closes the report panel", "Comment for tooltip Dismissbutton"));
-    QWhatsThis::add(m_pDismissbutt, tr("The dismiss button dismisses the report panel", "Comment for whatsThis Dsimissbutton"));
-    m_pSavebutt->setText(tr("Save", "Comment for Savebutton"));
-    QToolTip::add(m_pSavebutt, tr("Saves the report panel text", "Comment for tooltip Savebutton"));
-    QWhatsThis::add(m_pSavebutt, tr("The save button saves the report panel text to a file", "Comment for whatsThis Savebutton"));
+    m_pDismissbutt->setText(trUtf8("Dismiss", "Comment for Dismissbutton"));
+    QToolTip::add(m_pDismissbutt, trUtf8("Closes the report panel", "Comment for tooltip Dismissbutton"));
+    QWhatsThis::add(m_pDismissbutt, trUtf8("The dismiss button dismisses the report panel", "Comment for whatsThis Dsimissbutton"));
+    m_pSavebutt->setText(trUtf8("Save", "Comment for Savebutton"));
+    QToolTip::add(m_pSavebutt, trUtf8("Saves the report panel text", "Comment for tooltip Savebutton"));
+    QWhatsThis::add(m_pSavebutt, trUtf8("The save button saves the report panel text to a file", "Comment for whatsThis Savebutton"));
 
     // Inner tool buttons for new local report generation
-    m_pWeeklybutt->setText(tr("Weekly", "Comment for Weeklybutt"));
-    QToolTip::add(m_pWeeklybutt, tr("Hold down for options", "Comment for tooltip Weeklybutt"));
-    QWhatsThis::add(m_pWeeklybutt, tr("The weekly button generates a new weekly report.\nHold this button down to specify many weeks.", "Comment for whatsThis Weeklybutt"));
-    m_pMonthlybutt->setText(tr("Monthly", "Comment for Monthlybutt"));
-    QToolTip::add(m_pMonthlybutt, tr("Hold down for options", "Comment for tooltip Monthlybutt"));
-    QWhatsThis::add(m_pMonthlybutt, tr("The monthly button makes a new monthly report.\nHold this button down to specify how many months.", "Comment for whatsThis Monthlybutt"));
-    m_pBothbutt->setText(tr("Both", "Comment for Bothbutt"));
-    QToolTip::add(m_pBothbutt, tr("Report with both week data and month data", "Comment for tooltip Bothbutt"));
-    QWhatsThis::add(m_pBothbutt, tr("The both button makes a new report with both weekly and monthly items mixed in. Hold this button down to specify how many weeks mixed of data.", "Comment for whatsThis Bothbutt"));
+    m_pWeeklybutt->setText(trUtf8("Weekly", "Comment for Weeklybutt"));
+    QToolTip::add(m_pWeeklybutt, trUtf8("Hold down for options", "Comment for tooltip Weeklybutt"));
+    QWhatsThis::add(m_pWeeklybutt, trUtf8("The Weekly button generates a new weekly report.\nHold this button down to specify many weeks.", "Comment for whatsThis Weeklybutt"));
+    m_pMonthlybutt->setText(trUtf8("Monthly", "Comment for Monthlybutt"));
+    QToolTip::add(m_pMonthlybutt, trUtf8("Hold down for options", "Comment for tooltip Monthlybutt"));
+    QWhatsThis::add(m_pMonthlybutt, trUtf8("The Monthly button makes a new monthly report.\nHold this button down to specify how many months.", "Comment for whatsThis Monthlybutt"));
+    m_pBothbutt->setText(trUtf8("Both", "Comment for Bothbutt"));
+    QToolTip::add(m_pBothbutt, trUtf8("Report with both week data and month data", "Comment for tooltip Bothbutt"));
+    QWhatsThis::add(m_pBothbutt, trUtf8("The both button makes a new report with both weekly and monthly items mixed in. Hold this button down to specify how many weeks mixed of data.", "Comment for whatsThis Bothbutt"));
 }
 } // namespace AS
