@@ -99,8 +99,10 @@ private:
     void writeHeader(QString);
     void writeHeader(QString, QString);
     void writeFooter(void);
-    QString getWeek(QDate Refer = QDate::currentDate());
-    QString getMonth(QDate Refer = QDate::currentDate());
+    QString getWeektotals(QDate Refer = QDate::currentDate(), int nWeeks = 1);
+    QString getWeekdetails(QDate Refer = QDate::currentDate(), int nWeeks = 1);
+    QString getMonthtotals(QDate Refer = QDate::currentDate(), int nMonths = 1);
+    QString getMonthdetails(QDate Refer = QDate::currentDate(), int nMonths = 1);
 };
 } // namespace AS
 
