@@ -1153,6 +1153,8 @@ void Titraqform::configPrefs(void)
 #endif
     pUserpanel->setBackon(m_pPrefs->getBool(TITRAQ_PREFBAKON, TITRAQ_DEFBAKON));
     pUserpanel->setExtendon(m_pPrefs->getBool(TITRAQ_PREFEXTENDON, TITRAQ_DEFEXTENDON));
+    pUserpanel->setDetailon(m_pPrefs->getBool(TITRAQ_PREFDETAILON, TITRAQ_DEFDETAILON));
+    pUserpanel->setSignaton(m_pPrefs->getBool(TITRAQ_PREFSIGNATON, TITRAQ_DEFSIGNATON));
 
     // Set default style which can be more complicated due to mapping...
     switch (m_pPrefs->getNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE)) {
@@ -1179,6 +1181,29 @@ void Titraqform::configPrefs(void)
         break;
     }
 
+    // Colour preferences
+    int nRed, nGreen, nBlue;
+    QColorGroup Origcolour;
+    const QColor Origlight = QColor(TITRAQ_DEFLIGHTRED, TITRAQ_DEFLIGHTGREEN, TITRAQ_DEFLIGHTBLUE);
+    const QColor Origdark  = QColor(TITRAQ_DEFDARKRED, TITRAQ_DEFDARKGREEN, TITRAQ_DEFDARKBLUE);
+
+    // Set colours to revert to if user screws up and wants out
+    Origcolour.setColor(QColorGroup::Foreground, Origlight);
+    Origcolour.setColor(QColorGroup::Background, Origdark);
+    pUserpanel->setOrigcolour(&Origcolour);
+
+    // Set colour preferences saved from last session
+    nRed   = m_pPrefs->getNumber(TITRAQ_PREFLIGHTRED, TITRAQ_DEFLIGHTRED);
+    nGreen = m_pPrefs->getNumber(TITRAQ_PREFLIGHTGREEN, TITRAQ_DEFLIGHTGREEN);
+    nBlue  = m_pPrefs->getNumber(TITRAQ_PREFLIGHTBLUE, TITRAQ_DEFLIGHTBLUE);
+    const QColor Lightshade = QColor(nRed, nGreen, nBlue);
+    pUserpanel->setLight(&Lightshade);
+    nRed   = m_pPrefs->getNumber(TITRAQ_PREFDARKRED, TITRAQ_DEFDARKRED);
+    nGreen = m_pPrefs->getNumber(TITRAQ_PREFDARKGREEN, TITRAQ_DEFDARKGREEN);
+    nBlue  = m_pPrefs->getNumber(TITRAQ_PREFDARKBLUE, TITRAQ_DEFDARKBLUE);
+    const QColor Darkshade = QColor(nRed, nGreen, nBlue);
+    pUserpanel->setDark(&Darkshade);
+
     // Modal panel handler
     if (pUserpanel->exec() == QDialog::Accepted)
         this->applyPrefs(pUserpanel);
@@ -1905,6 +1930,14 @@ void Titraqform::applyPrefs(Prefpanel *pPrefpanel)
     m_pPrefs->setBool(TITRAQ_PREFSOAPON, pPrefpanel->getSoapon());
     m_pPrefs->setBool(TITRAQ_PREFBAKON, pPrefpanel->getBackon());
     m_pPrefs->setBool(TITRAQ_PREFEXTENDON, pPrefpanel->getExtendon());
+    m_pPrefs->setBool(TITRAQ_PREFDETAILON, pPrefpanel->getDetailon());
+    m_pPrefs->setBool(TITRAQ_PREFSIGNATON, pPrefpanel->getSignaton());
+    m_pPrefs->setNumber(TITRAQ_PREFLIGHTRED, pPrefpanel->getLight()->red());
+    m_pPrefs->setNumber(TITRAQ_PREFLIGHTGREEN, pPrefpanel->getLight()->green());
+    m_pPrefs->setNumber(TITRAQ_PREFLIGHTBLUE, pPrefpanel->getLight()->blue());
+    m_pPrefs->setNumber(TITRAQ_PREFDARKRED, pPrefpanel->getDark()->red());
+    m_pPrefs->setNumber(TITRAQ_PREFDARKGREEN, pPrefpanel->getDark()->green());
+    m_pPrefs->setNumber(TITRAQ_PREFDARKBLUE, pPrefpanel->getDark()->blue());
 
     // Dim the lights if no RPC transports are available
     if (this->isOpen())
